@@ -613,7 +613,6 @@ class ApiManager:
                         )
                     )
 
-
             used_templates = []
             template_id_to_name = {}
 
@@ -785,11 +784,9 @@ class ApiManager:
                     keys = func_id.split(".")
 
                     if exists["pipeline_id"] is not None:
-
                         migrated_funcs[keys[-1]] = exists["pipeline_id"]
 
                     if func_id not in migrated_funcs and exists["pipeline_id"] is None:
-
                         resp = json.loads(
                             self.proceses_importing_pipeline_file(
                                 org_id=org_id,
@@ -896,6 +893,15 @@ class ApiManager:
                 if component["jsonClass"] == "JsonFunctionApply":
                     component["pipelineId"] = migrated_funcs[str(component["pipelineId"])]
 
+                if component["jsonClass"] == "JsonGraphsV2Sink":
+                    component["orgId"] = org_id
+                    component["graphId"] = str(uuid.uuid4())
+
+                if component["jsonClass"] == "JsonDatasetsSink":
+                    component["orgId"] = org_id
+                    component["datasetId"] = str(uuid.uuid4())
+
+
             pipeline = self.pipelines.create_pipeline(
                 org_id=org_id,
                 name=data["pipeline"]["pipeline"]["data"]["name"],
