@@ -19,6 +19,7 @@ client service
 import json
 import requests
 
+
 class ApiRequestManager:
     """
     Class to interact with general api request methods
@@ -41,6 +42,20 @@ class ApiRequestManager:
         self.cluster = cluster
         self.evergreen_enabled = True
 
+        auth = self.props.get_auth_token(cluster=self.cluster)
+
+        if auth is None or len(auth) == 0:
+            self.props.set_auth_token(
+                token=self.auth_token(),
+                cluster=self.cluster
+            )
+
+        self.session.headers.update(
+            {
+                self.x_auth_token_header: self.props.get_auth_token(cluster=self.cluster)
+            }
+        )
+
     def close_session(self):
         """
         Closes request session
@@ -104,7 +119,6 @@ class ApiRequestManager:
             )
 
             if post_response.status_code == 200:
-
                 return json.loads(post_response.content)["authToken"]
 
             raise Exception(post_response.content)
