@@ -1,3 +1,17 @@
+# Copyright 2021 Element Analytics, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
 Contains methods to interact with organization api
 """
@@ -89,9 +103,7 @@ class OrgAdmin(ApiRequestManager):
 
             org_create_post = self.session.post(
                 self.orgs_api_url,
-                headers=self.build_header(
-                    aut_token=self.props.get_auth_token(cluster=self.cluster),
-                    others=self.content_type_header),
+                headers=self.build_header(others=self.content_type_header),
                 data=json.dumps(payload)
             )
 
@@ -119,10 +131,7 @@ class OrgAdmin(ApiRequestManager):
             ) + 'api/management/v1/orgs/' + str(org_id)
 
             delete_request = self.session.delete(
-                delete_endpoint,
-                headers=self.build_header(
-                    aut_token=self.props.get_auth_token(cluster=self.cluster)
-                )
+                delete_endpoint
             )
 
             if delete_request.status_code == 200:
@@ -152,7 +161,6 @@ class OrgAdmin(ApiRequestManager):
             invite_user_url = self.org_info_url.format(org_id) + '/users'
 
             header = self.build_header(
-                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 org_id=org_id,
                 others=self.content_type_header
             )
@@ -186,14 +194,13 @@ class OrgAdmin(ApiRequestManager):
         :type password: str
         :param role: User role. Accepts "Admin" or "Contributor"
         :type role: str
-        :return: Invite machine user status messae
+        :return: Invite machine user status message
         """
         try:
 
             invite_machine_user_url = self.org_info_url.format(org_id) + '/machine_users'
 
             header = self.build_header(
-                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 org_id=org_id,
                 others=self.content_type_header
             )
@@ -227,14 +234,9 @@ class OrgAdmin(ApiRequestManager):
         """
         try:
 
-            header = self.build_header(
-                aut_token=self.props.get_auth_token(cluster=self.cluster)
-            )
-
             request = self.session.get(
                 '{}api/whoami'.format(
-                    self.props.get_remote(cluster=self.cluster)),
-                headers=header
+                    self.props.get_remote(cluster=self.cluster))
             )
 
             if request.status_code == 200:
