@@ -1,3 +1,17 @@
+# Copyright 2021 Element Analytics, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     https://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """
 Contains methods to interact with templates api
 """
@@ -96,7 +110,6 @@ class Templates(ApiRequestManager):
             file_upload = {'file': file_path}
 
         upload_headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
 
@@ -124,7 +137,6 @@ class Templates(ApiRequestManager):
         final_url = self.template_attribute.format(org_id, template_id)
 
         upload_headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
 
@@ -153,7 +165,6 @@ class Templates(ApiRequestManager):
         files = {'file': ('templates_uploads.csv', content, self.upload_content_type)}
 
         upload_headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
 
@@ -210,7 +221,6 @@ class Templates(ApiRequestManager):
         }
 
         upload_headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
 
@@ -229,7 +239,6 @@ class Templates(ApiRequestManager):
     def _add_category(self, org_id, category):
         url = self.categories_url.format(org_id)
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -255,7 +264,6 @@ class Templates(ApiRequestManager):
         :return: List of template categories
         """
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
         )
         request = self.session.get(
@@ -298,7 +306,6 @@ class Templates(ApiRequestManager):
 
         url = '{}/{}?version={}'.format(self.template_url, template_id, version)
         headers = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -330,7 +337,6 @@ class Templates(ApiRequestManager):
         :return: Retrieved template str
         """
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
         url = self.template_url + '/' + str(template_id)
@@ -352,7 +358,6 @@ class Templates(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id
         )
 
@@ -376,7 +381,6 @@ class Templates(ApiRequestManager):
         """
 
         header = self.build_header(
-            aut_token=self.props.get_auth_token(cluster=self.cluster),
             org_id=org_id,
             others=self.content_type_header
         )
@@ -427,7 +431,6 @@ class Templates(ApiRequestManager):
         try:
 
             header = self.build_header(
-                aut_token=self.props.get_auth_token(cluster=self.cluster),
                 org_id=org_id
             )
             url = self.template_batch_url.format(org_id)
@@ -464,7 +467,7 @@ class Templates(ApiRequestManager):
                             attribute_config.get("value")])
 
             data = "\n".join([",".join(row) for row in config_array])
-        
+
             return data
 
         except Exception as error:
